@@ -18,3 +18,5 @@ DATABASE_ECHO = config.getboolean('DATABASE', 'echo')
 
 TEST_XML_URL_DATA_STATION = config.get('TEST', 'url_data_station')
 
+PROXY_SERVERS = config.get('PROXY', 'servers')
+PROXY_SERVERS = PROXY_SERVERS and PROXY_SERVERS.split(';') or []
